# Errors

This section contains the `distilabel` custom errors. Unlike [exceptions](exceptions.md), errors in `distilabel` are used to handle unexpected situations that can't be anticipated and that can't be handled in a controlled way.

:::distilabel.errors.DistilabelError
:::distilabel.errors.DistilabelUserError
:::distilabel.errors.DistilabelTypeError
:::distilabel.errors.DistilabelNotImplementedError
